summaryrefslogtreecommitdiffstats
path: root/kcontrol/colors
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
commit73c08b592db45af554b9f21029bc549d70f683ab (patch)
tree122898ea951e59fdc4419b3c84b7a6c2dd0bb5f7 /kcontrol/colors
parente81bdee8ae92d6eeb82daa8c0a0e46bf37f4a6da (diff)
downloadtdebase-73c08b592db45af554b9f21029bc549d70f683ab.tar.gz
tdebase-73c08b592db45af554b9f21029bc549d70f683ab.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kcontrol/colors')
-rw-r--r--kcontrol/colors/colorscm.cpp12
-rw-r--r--kcontrol/colors/widgetcanvas.cpp14
2 files changed, 13 insertions, 13 deletions
diff --git a/kcontrol/colors/colorscm.cpp b/kcontrol/colors/colorscm.cpp
index 2a9085b97..b68b234b3 100644
--- a/kcontrol/colors/colorscm.cpp
+++ b/kcontrol/colors/colorscm.cpp
@@ -16,7 +16,7 @@
#include <tqcombobox.h>
#include <tqdir.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqslider.h>
#include <tqvgroupbox.h>
@@ -440,7 +440,7 @@ void KColorScheme::sliderValueChanged( int val )
void KColorScheme::slotSave( )
{
- KColorSchemeEntry *entry = mSchemeList->tqat(sList->currentItem()-nSysSchemes);
+ KColorSchemeEntry *entry = mSchemeList->at(sList->currentItem()-nSysSchemes);
if (!entry) return;
sCurrentScheme = entry->path;
KSimpleConfig *config = new KSimpleConfig(sCurrentScheme );
@@ -482,7 +482,7 @@ void KColorScheme::slotSave( )
void KColorScheme::slotRemove()
{
uint ind = sList->currentItem();
- KColorSchemeEntry *entry = mSchemeList->tqat(ind-nSysSchemes);
+ KColorSchemeEntry *entry = mSchemeList->at(ind-nSysSchemes);
if (!entry) return;
if (unlink(TQFile::encodeName(entry->path).data())) {
@@ -497,7 +497,7 @@ void KColorScheme::slotRemove()
mSchemeList->remove(entry);
ind = sList->currentItem();
- entry = mSchemeList->tqat(ind-nSysSchemes);
+ entry = mSchemeList->at(ind-nSysSchemes);
if (!entry) return;
removeBt->setEnabled(entry ? entry->local : false);
}
@@ -795,7 +795,7 @@ void KColorScheme::readScheme( int index )
config->setGroup("General");
} else {
// Open scheme file
- KColorSchemeEntry *entry = mSchemeList->tqat(sList->currentItem()-nSysSchemes);
+ KColorSchemeEntry *entry = mSchemeList->at(sList->currentItem()-nSysSchemes);
if (!entry) return;
sCurrentScheme = entry->path;
config = new KSimpleConfig(sCurrentScheme, true);
@@ -941,7 +941,7 @@ void KColorScheme::slotPreviewScheme(int indx)
removeBt->setEnabled(false);
else
{
- KColorSchemeEntry *entry = mSchemeList->tqat(indx-nSysSchemes);
+ KColorSchemeEntry *entry = mSchemeList->at(indx-nSysSchemes);
removeBt->setEnabled(entry ? entry->local : false);
}
diff --git a/kcontrol/colors/widgetcanvas.cpp b/kcontrol/colors/widgetcanvas.cpp
index 450b140a5..f9fd0a97f 100644
--- a/kcontrol/colors/widgetcanvas.cpp
+++ b/kcontrol/colors/widgetcanvas.cpp
@@ -327,7 +327,7 @@ void WidgetCanvas::drawSampleWidgets()
#ifndef __osf__
TQPainter::redirect( vertScrollBar, &pm );
#endif
- vertScrollBar->tqrepaint();
+ vertScrollBar->repaint();
TQPainter::redirect( vertScrollBar, 0 );
vertScrollBar->hide();
@@ -338,7 +338,7 @@ void WidgetCanvas::drawSampleWidgets()
smplw.resize(width(), height());
//smplw.fill( parentWidget()->back() );
- smplw.fill( parentWidget()->tqcolorGroup().mid() );
+ smplw.fill( parentWidget()->colorGroup().mid() );
// Actually start painting in
@@ -567,9 +567,9 @@ void WidgetCanvas::drawSampleWidgets()
popup->setItemEnabled( id, false );
// HACK: Force Layouting
- //Sad Eagle: tqsizeHint() forces layouting too, and it's a lot less visible
- //popup->tqsizeHint(); // Breaks with Qt 3.3
- popup->resize(popup->tqsizeHint());
+ //Sad Eagle: sizeHint() forces layouting too, and it's a lot less visible
+ //popup->sizeHint(); // Breaks with Qt 3.3
+ popup->resize(popup->sizeHint());
pm = TQPixmap::grabWidget( popup );
delete popup;
@@ -585,12 +585,12 @@ void WidgetCanvas::drawSampleWidgets()
// Valance
qDrawWinPanel ( &paint, 0, 0, width(), height(),
- parentWidget()->tqcolorGroup(), TRUE, 0);
+ parentWidget()->colorGroup(), TRUE, 0);
// Stop the painting
hotspots[ spot++ ] =
HotSpot( TQRect( 0, 0, width(), height() ), CSM_Background ); // ?
- tqrepaint( FALSE );
+ repaint( FALSE );
}